@@ -24,15 +24,16 @@ $my_graph->set(
 
 $my_graph->set_legend( 'Data set 1', 'Data set 2' );
 
-open GIF, ">sample12.gif";
-print GIF $my_graph->plot(\@data)->gif;
-close GIF;
+open PNG, ">sample12.png";
+binmode PNG; #only for Windows like platforms
+print PNG $my_graph->plot(\@data)->png;
+close PNG;
 
 $map = new GD::Graph::Map($my_graph, info => '%l:  x=%x    y=%y');
 
 open HTML, ">sample12.html";
-print HTML "<HTML><BODY>\n".
-  ($map->imagemap("sample12.gif", \@data)).
+print HTML "<HTML><BODY BGCOLOR=white>\n".
+  ($map->imagemap("sample12.png", \@data)).
   "</BODY></HTML>";
 close HTML;
 
