@@ -33,15 +33,16 @@ $my_graph->set(
 
 $my_graph->set_legend("Us", "Them", "Others");
 
-open GIF, ">sample52.gif";
-print GIF $my_graph->plot(\@data)->gif;
-close GIF;
+open PNG, ">sample52.png";
+binmode PNG; #only for Windows like platforms
+print PNG $my_graph->plot(\@data)->png;
+close PNG;
 
 $map = new GD::Graph::Map($my_graph, info => '%l');
 
 open HTML, ">sample52.html";
-print HTML "<HTML><BODY>\n".
-  ($map->imagemap("sample52.gif", \@data)).
+print HTML "<HTML><BODY BGCOLOR=white>\n".
+  ($map->imagemap("sample52.png", \@data)).
   "</BODY></HTML>";
 close HTML;
 
