@@ -19,15 +19,16 @@ $my_graph->set(
 	pie_height 	=> 70,
 );
 
-open GIF, ">sample92.gif";
-print GIF $my_graph->plot(\@data)->gif;
-close GIF;
+open PNG, ">sample92.png";
+binmode PNG; #only for Windows like platforms
+print PNG $my_graph->plot(\@data)->png;
+close PNG;
 
 $map = new GD::Graph::Map($my_graph, info => '%x:  %y (%p%)');
 
 open HTML, ">sample92.html";
-print HTML "<HTML><BODY>\n".
-  ($map->imagemap("sample92.gif", \@data)).
+print HTML "<HTML><BODY BGCOLOR=white>\n".
+  ($map->imagemap("sample92.png", \@data)).
   "</BODY></HTML>";
 close HTML;
 
